#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Automated Audio Captioning Datasets package.
"""

from .datasets.audiocaps import AudioCaps
from .datasets.clotho import Clotho
from .datasets.macs import MACS


__author__ = "Etienne Labbé (Labbeti)"
__maintainer__ = "Etienne Labbé (Labbeti)"
__name__ = "aac-datasets"
__status__ = "Development"
__version__ = "0.2.0"
